@@ -6,7 +6,7 @@
  * Copyright (C) 2000, 2002 - Chema Celorio, Paolo Maggi
  * Copyright (C) 2003-2005 - Paolo Maggi
  *
- * Copyright (C) 2014 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2014, 2015, 2017 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * LaTeXila is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,9 +25,9 @@
 /**
  * SECTION:utils
  * @title: LatexilaUtils
- * @short_description: Utilities functions
+ * @short_description: Utility functions
  *
- * Various utilities functions.
+ * Various utility functions.
  */
 
 #include "latexila-utils.h"
@@ -304,7 +304,7 @@ default_document_viewer_is_evince (const gchar *uri)
 
 /**
  * latexila_utils_show_uri:
- * @screen: (nullable): a #GdkScreen, or %NULL.
+ * @widget: (nullable): the associated #GtkWidget, or %NULL.
  * @uri: the URI to show.
  * @timestamp: a timestamp.
  * @error: (out) (optional): a %NULL #GError, or %NULL.
@@ -314,15 +314,28 @@ default_document_viewer_is_evince (const gchar *uri)
  * backward search works (switch from the PDF to the source file).
  */
 void
-latexila_utils_show_uri (GdkScreen    *screen,
+latexila_utils_show_uri (GtkWidget    *widget,
                          const gchar  *uri,
                          guint32       timestamp,
                          GError      **error)
 {
+  GtkWindow *parent = NULL;
+
+  g_return_if_fail (widget == NULL || GTK_IS_WIDGET (widget));
   g_return_if_fail (uri != NULL);
   g_return_if_fail (error == NULL || *error == NULL);
 
-  if (gtk_show_uri (screen, uri, timestamp, error))
+  if (widget != NULL)
+    {
+      GtkWidget *toplevel;
+
+      toplevel = gtk_widget_get_toplevel (widget);
+      if (gtk_widget_is_toplevel (toplevel) &&
+          GTK_IS_WINDOW (toplevel))
+        parent = GTK_WINDOW (toplevel);
+    }
+
+  if (gtk_show_uri_on_window (parent, uri, timestamp, error))
     {
       gchar *extension = latexila_utils_get_extension (uri);
 
@@ -336,3 +349,123 @@ latexila_utils_show_uri (GdkScreen    *screen,
       g_free (extension);
     }
 }
+
+/**
+ * latexila_utils_get_dialog_component:
+ * @title: the title of the dialog component.
+ * @widget: the widget displayed below the title.
+ *
+ * Gets a #GtkDialog component. When a dialog contains several components, or
+ * logical groups, this function is useful to attach the @widget with a @title.
+ * The title will be in bold, left-aligned, and the widget will have a left
+ * margin.
+ *
+ * Returns: (transfer floating): the dialog component containing the @title and
+ * the @widget.
+ */
+GtkWidget *
+latexila_utils_get_dialog_component (const gchar *title,
+                                     GtkWidget   *widget)
+{
+  GtkContainer *grid;
+  GtkWidget *label;
+  gchar *markup;
+
+  grid = GTK_CONTAINER (gtk_grid_new ());
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (grid), GTK_ORIENTATION_VERTICAL);
+  gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+  gtk_container_set_border_width (grid, 6);
+
+  /* Title in bold, left-aligned. */
+  label = gtk_label_new (NULL);
+  markup = g_strdup_printf ("<b>%s</b>", title);
+  gtk_label_set_markup (GTK_LABEL (label), markup);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_container_add (grid, label);
+
+  /* Left margin for the widget. */
+  gtk_widget_set_margin_start (widget, 12);
+  gtk_container_add (grid, widget);
+
+  g_free (markup);
+  return GTK_WIDGET (grid);
+}
+
+/**
+ * latexila_utils_create_parent_directories:
+ * @file: a file
+ * @error: (out) (optional): a location to a %NULL #GError, or %NULL.
+ *
+ * Synchronously creates parent directories of @file, so that @file can be
+ * saved.
+ *
+ * Returns: whether the directories are correctly created. %FALSE is returned on
+ * error.
+ */
+gboolean
+latexila_utils_create_parent_directories (GFile   *file,
+                                          GError **error)
+{
+  GFile *parent;
+  GError *my_error = NULL;
+
+  g_return_val_if_fail (G_IS_FILE (file), FALSE);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+  parent = g_file_get_parent (file);
+
+  if (parent == NULL)
+    return TRUE;
+
+  g_file_make_directory_with_parents (parent, NULL, &my_error);
+  g_object_unref (parent);
+
+  if (my_error != NULL)
+    {
+      if (g_error_matches (my_error, G_IO_ERROR, G_IO_ERROR_EXISTS))
+        {
+          g_error_free (my_error);
+          return TRUE;
+        }
+      else
+        {
+          g_propagate_error (error, my_error);
+          return FALSE;
+        }
+    }
+
+  return TRUE;
+}
+
+/**
+ * latexila_utils_join_widgets:
+ * @widget_top: the #GtkWidget at the top.
+ * @widget_bottom: the #GtkWidget at the bottom.
+ *
+ * Joins two widgets vertically, with junction sides.
+ *
+ * Returns: (transfer floating): a #GtkContainer containing @widget_top and
+ * @widget_bottom.
+ */
+GtkWidget *
+latexila_utils_join_widgets (GtkWidget *widget_top,
+                             GtkWidget *widget_bottom)
+{
+  GtkStyleContext *context;
+  GtkBox *vbox;
+
+  g_return_val_if_fail (GTK_IS_WIDGET (widget_top), NULL);
+  g_return_val_if_fail (GTK_IS_WIDGET (widget_bottom), NULL);
+
+  context = gtk_widget_get_style_context (widget_top);
+  gtk_style_context_set_junction_sides (context, GTK_JUNCTION_BOTTOM);
+
+  context = gtk_widget_get_style_context (widget_bottom);
+  gtk_style_context_set_junction_sides (context, GTK_JUNCTION_TOP);
+
+  vbox = GTK_BOX (gtk_box_new (GTK_ORIENTATION_VERTICAL, 0));
+  gtk_box_pack_start (vbox, widget_top, TRUE, TRUE, 0);
+  gtk_box_pack_start (vbox, widget_bottom, FALSE, FALSE, 0);
+
+  return GTK_WIDGET (vbox);
+}
